@@ -1,11 +1,29 @@
+use strict;
+use warnings;
 package DAIA;
 {
-  $DAIA::VERSION = '0.35';
+  $DAIA::VERSION = '0.4';
 }
 #ABSTRACT: Document Availability Information API
 
-use strict;
-
+# we do not want depend on the following modules
+our ($TRINE_MODEL, $TRINE_SERIALIZER, $RDF_NS, $GRAPHVIZ);
+BEGIN {
+    # optionally use RDF::Trine::Serializer
+    $TRINE_MODEL = 'RDF::Trine::Model';
+    $TRINE_SERIALIZER = 'RDF::Trine::Serializer';
+    eval "use $TRINE_MODEL; use $TRINE_SERIALIZER";
+    if ($@) {
+        $TRINE_MODEL = undef;
+        $TRINE_SERIALIZER = undef;
+    }
+    # optionally use RDF::NS
+    eval "use RDF::NS";
+    $RDF_NS = eval "RDF::NS->new('any')" unless $@;
+    # optionally use RDF::Trine::Exporter::GraphViz
+    eval "use RDF::Trine::Exporter::GraphViz";
+    $GRAPHVIZ = 'RDF::Trine::Exporter::GraphViz' unless $@;
+}
 
 use base 'Exporter';
 our %EXPORT_TAGS = (
@@ -14,7 +32,7 @@ our %EXPORT_TAGS = (
 );
 our @EXPORT_OK = qw(is_uri parse guess);
 Exporter::export_ok_tags;
-$EXPORT_TAGS{all} = [@EXPORT_OK, 'message', 'serve', 'error'];
+$EXPORT_TAGS{all} = [@EXPORT_OK, 'message', 'serve'];
 Exporter::export_tags('all');
 
 use Carp; # use Carp::Clan; # qw(^DAIA::);
@@ -29,7 +47,6 @@ use DAIA::Availability;
 use DAIA::Available;
 use DAIA::Unavailable;
 use DAIA::Message;
-use DAIA::Error;
 use DAIA::Entity;
 use DAIA::Institution;
 use DAIA::Department;
@@ -39,6 +56,8 @@ use DAIA::Limitation;
 use Data::Validate::URI qw(is_uri);
 
 
+
+
 sub response     { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Response->new( @_ ) }
 sub document     { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Document->new( @_ ) }
 sub item         { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Item->new( @_ ) }
@@ -51,13 +70,6 @@ sub department   { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::D
 sub storage      { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Storage->new( @_ ) }
 sub limitation   { local $Carp::CarpLevel = $Carp::CarpLevel + 1; return DAIA::Limitation->new( @_ ) }
 
-sub error { 
-    local $Carp::CarpLevel = $Carp::CarpLevel + 1; 
-    #my $errno = @_ ? shift : 0;
-    #return DAIA::Message->new( @_ ? (@_, errno => $errno) : (errno => $errno) );
-    return DAIA::Error->new( @_ );
-}
-
 
 sub serve {
     local $Carp::CarpLevel = $Carp::CarpLevel + 1; 
@@ -88,13 +100,13 @@ sub parse {
             $from = get($file) or croak "Failed to fetch $file via HTTP"; 
         } else {
             if ( ! (ref($file) eq 'GLOB' or UNIVERSAL::isa( $file, 'IO::Handle') ) ) {
-                $file = do { IO::File->new($file, '<:utf8') or croak("Failed to open file $file") };
+                $file = do { IO::File->new($file, '<:encoding(UTF-8)') or croak("Failed to open file $file") };
             }
-            # Enable :utf8 layer unless it or some other encoding has already been enabled
+            # Enable :encoding(UTF-8) layer unless it or some other encoding has already been enabled
             # foreach my $layer ( PerlIO::get_layers( $file ) ) {
             #    return if $layer =~ /^encoding|^utf8/;
             #}
-            binmode $file, ':utf8';
+            binmode $file, ':encoding(UTF-8)';
             $from = do { local $/; <$file> };
         }
         croak "DAIA serialization is empty" unless $from;
@@ -194,6 +206,28 @@ sub guess {
 }
 
 
+sub formats {
+    shift if UNIVERSAL::isa( $_[0], __PACKAGE__ );
+    my %formats = (
+        xml  => 'application/xml; charset=utf-8',
+        json => 'application/javascript; charset=utf-8',
+        rdfjson => 'application/javascript; charset=utf-8',
+    );
+
+    if ($TRINE_SERIALIZER) {
+        $formats{'rdfxml'} = 'application/rdf+xml; charset=utf-8',;
+        $formats{'turtle'} = 'text/turtle; charset=utf-8';
+        $formats{'ntriples'} = 'text/plain';
+    }
+    if ($GRAPHVIZ) {
+        $formats{'svg'} = 'image/svg+xml';
+        $formats{'dot'} = 'text/plain; charset=utf-8';
+    }
+
+    return %formats;
+}
+
+
 #### internal methods (subject to be changed)
 
 my $NSEXPDAIA    = qr/{http:\/\/(ws.gbv.de|purl.org\/ontology)\/daia\/}(.*)/;
@@ -280,7 +314,7 @@ DAIA - Document Availability Information API
 
 =head1 VERSION
 
-version 0.35
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -397,12 +431,11 @@ implemented as object of class L<DAIA::Response>.
 =back
 
 Additional L<DAIA objects|/"DAIA OBJECTS"> include B<institutions>
-(L<DAIA::Institution>), B<departments> (L<DAIA::Department>), 
-storages (L<DAIA::Storage>), messages (L<DAIA::Message>), and 
-errors (L<DAIA::Message>). All these objects provide standard methods
-for creation, modification, and serialization. This package also
-L<exports functions|/"FUNCTIONS"> as shorthand for object constructors,
-for instance the following two result in the same:
+(L<DAIA::Institution>), B<departments> (L<DAIA::Department>), storages
+(L<DAIA::Storage>), messages and errors (L<DAIA::Message>).  All these objects
+provide standard methods for creation, modification, and serialization. This
+package also L<exports functions|/"FUNCTIONS"> as shorthand for object
+constructors, for instance the following two result in the same:
 
   item( id => $id );
   DAIA::Item->new( id => $id );
@@ -431,7 +464,7 @@ C<institution>, C<department>, C<storage>, C<limitation>
 
 =back
 
-Additional functions are C<message> and C<error> as object constructors,
+Additional functions are C<message> as object constructor,
 and C<serve>. The other functions below are not exported by default.
 You can call them as method or as function, for instance:
 
@@ -505,6 +538,10 @@ filename, a string of XML, or a L<IO::Handle> object.
 Guess serialization format (DAIA/JSON or DAIA/XML) and return C<json>, C<xml> 
 or the empty string.
 
+=head2 formats
+
+Return a has with allowed serialization formats and their mime types.
+
 =head2 is_uri ( $value )
 
 Checks whether the value is a well-formed URI. This function is imported from
@@ -514,9 +551,9 @@ On request the function can be exported into the default namespace.
 =head1 DAIA OBJECTS
 
 All objects (documents, items, availability status, institutions, departments,
-limitations, storages, messages, errors) are implemented as subclass of
-L<DAIA::Object>, which is just another Perl meta-class framework.
-All objects have the following methods:
+limitations, storages, messages) are implemented as subclass of
+L<DAIA::Object>, which is just another Perl meta-class framework.  All objects
+have the following methods:
 
 =head2 item
 
